# -*- coding: utf-8 -*-

from enum import Enum

from fastapi import APIRouter, HTTPException, Query
from loguru import logger

from app.controllers.equipment.vav import VAVController
from app.models.equipment import EquipmentControlInResponse
from app.utils.date import get_time_str


class EquipmentName(str, Enum):
    FCU = 'ATFC'
    VAV = 'ATVA'


router = APIRouter()


@router.get('/control', response_model=EquipmentControlInResponse, tags=['equipment'])
async def get_equipment_command(
        projectId: str = Query(..., max_length=50, regex='^Pj'),
        equipId: str = Query(..., max_length=50, regex='^Eq'),
        equipType: EquipmentName = Query(...),
        method: int = Query(3),
):
    response = {
        'projectId': projectId,
        'equipId': equipId,
        'method': method,
        'flag': 1,
        'time': get_time_str(),
        'output': {}
    }
    return response
