# -*- coding: utf-8 -*-

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel

from app.models.space import Space


class AirValveSpeed(int, Enum):
    off = 0
    low = 1
    medium = 2
    high = 3
    auto = -1


class BaseEquipment(BaseModel):
    id: str
    running_status: Optional[bool] = False
    setting_temperature: Optional[float] = 0.0


class FCU(BaseEquipment):
    air_valve_speed: Optional[AirValveSpeed] = AirValveSpeed.off
    water_valve_status: Optional[bool] = False
    space: Optional[Space]


class VAVBox(BaseEquipment):
    spaces: Optional[List[Space]]
    supply_air_temperature: Optional[float]
    supply_air_flow: Optional[float]
    supply_air_flow_set: Optional[float]


class EquipmentControlInResponse(BaseModel):
    result: str = 'success'
    projectId: str
    equipId: str
    method: int
    flag: int
    time: str
    output: dict
